==> babel-plugin-flow-react-proptypes-0.7.1.tgz: package/lib/__test__/fixtures/import-object.output.js <==
'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _possibleConstructorReturn(self, call) {
  if (!self) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }return call && ((typeof call === "undefined" ? "undefined" : _typeof(call)) === "object" || typeof call === "function") ? call : self;
}

function _inherits(subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function, not " + (typeof superClass === "undefined" ? "undefined" : _typeof(superClass)));
  }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } });if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
}

var babelPluginFlowReactPropTypes_proptype_SomeType = require('./type').babelPluginFlowReactPropTypes_proptype_SomeType || React.PropTypes.any;

var C = function (_React$Component) {
  _inherits(C, _React$Component);

  function C() {
    _classCallCheck(this, C);

    return _possibleConstructorReturn(this, Object.getPrototypeOf(C).apply(this, arguments));
  }

  return C;
}(React.Component);

C.propTypes = {
  an_imported_type: babelPluginFlowReactPropTypes_proptype_SomeType,
  a_global_type: require('react').PropTypes.any.isRequired,
  a_undefined_type: require('react').PropTypes.any.isRequired
};
;

==> babel-plugin-flow-react-proptypes-0.7.2.tgz: package/lib/__test__/fixtures/import-object.output.js <==
'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _possibleConstructorReturn(self, call) {
  if (!self) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }return call && ((typeof call === "undefined" ? "undefined" : _typeof(call)) === "object" || typeof call === "function") ? call : self;
}

function _inherits(subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function, not " + (typeof superClass === "undefined" ? "undefined" : _typeof(superClass)));
  }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } });if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
}

var babelPluginFlowReactPropTypes_proptype_SomeType = require('./type').babelPluginFlowReactPropTypes_proptype_SomeType || require('react').PropTypes.any;

var C = function (_React$Component) {
  _inherits(C, _React$Component);

  function C() {
    _classCallCheck(this, C);

    return _possibleConstructorReturn(this, Object.getPrototypeOf(C).apply(this, arguments));
  }

  return C;
}(React.Component);

C.propTypes = {
  an_imported_type: babelPluginFlowReactPropTypes_proptype_SomeType,
  a_global_type: require('react').PropTypes.any.isRequired,
  a_undefined_type: require('react').PropTypes.any.isRequired
};
;
